##################################################
##                                              ##
##           BLOGPOST 2: SOTU ANALYSIS          ##
##                                              ##
##     Seminar Poltischer Datenjournalismus     ##
##         Nikolai Thelitz, 12.04.2014          ##
##                                              ##
##################################################

# Presets
rm(list=ls(all=TRUE)) # Alles bisherige im Arbeitssprecher löschen
setwd("~/Dropbox/Studium/MA/FS 2014/FS Datenjournalismus/Blogpost 2") # Arbeitsordner bestimmen 
options(stringsAsFactors=F) # Das automatische Bilden von Faktoren in dataframes verhindern

# Packages
library(tm) # Vielseitiges Textberarbeitungstool
library(ggplot2) # Um Resultate zu visualisieren
library(stringr) # Regular Expressions
library(qdap) # Sentiment Analysis
library(data.table)
library(directlabels)


hist <- read.csv("sotu-hist.csv", sep = ";")
hist$date <- as.Date(hist$date, format ="%B %d, %Y")

## Exploratory Analysis ##
plot(hist$date, hist$grade, size = hist$words, group = hist$form, bty="n", col = factor(hist$form))
barplot(hist$words, col = factor(hist$form), border = FALSE, names.arg=hist$years)

## History Plot ##

p <- ggplot(data = hist, aes(x = as.Date(hist$date, format('%Y-%m-%d')), y = as.numeric(hist$words), fill = factor(hist$form), color =  factor(hist$form), stat = "identity"))
p + 
geom_bar(width=0.8, stat = "identity") + 
theme(panel.background = element_blank(),
      panel.grid.major.x = element_blank(),
      panel.grid.minor.x = element_blank(),
      panel.border=element_blank(),
      axis.title.x = element_blank(),
      legend.position="bottom") +
  guides (color=FALSE)+
  scale_fill_discrete(name  ="Type",
                        breaks=c("written", "spoken"),
                        labels=c("written", "spoken")) +
  ggtitle("Length of State of the Union Adresses") +
  ylab("Length in Words")

## Guardian Plot ##

p <- ggplot(data = hist, aes(x=as.Date(hist$date, format('%Y-%m-%d')), y=as.numeric(hist$grade), fill = factor(hist$form), color = factor(hist$form),size = sqrt(hist$words)))
p + 
  geom_point() + 
  theme(panel.background = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border=element_blank(),
        axis.title.x = element_blank(),
        legend.position="bottom") +
  guides ( fill = FALSE, size=FALSE, alpha = FALSE)+
  scale_color_discrete(name  ="Type") +
  ggtitle("Declining Complexity in SOTU Adresses") +
  ylab("Fletsch-Kincaid Reading Level")

## Publicity Plot ##

p <- ggplot(data = hist, aes(x=as.Date(hist$date, format('%Y-%m-%d')), y=as.numeric(hist$grade), fill = hist$broadcast, color = hist$broadcast,size = sqrt(hist$words)))
p + 
  geom_point() + 
  theme(panel.background = element_blank(),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border=element_blank(),
        axis.title.x = element_blank(),
        legend.position="bottom") +
  guides ( fill = FALSE, size=FALSE, alpha = FALSE)+
  scale_color_discrete(name  ="Broadcast Type") +
  ggtitle("More Publicity, Less Complexity") +
  ylab("Fletsch-Kincaid Reading Level")

## Sentiment Ananlysis ##

sotu2009.raw <- paste(scan(file = "speeches/sotu2009.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2009 <- data.table(speech=sotu2009.raw, person="Obama")
sentences2009 <- data.table(sentSplit(sotu2009, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2009$sentence.num  <- seq(nrow(sentences2009))
# Syllables per sentence
sentences2009$syllables <- syllable_sum(sentences2009$speech)
#cumulative syllable count
sentences2009$cumsum <- cumsum(sentences2009$syllables)
#Progress in pct.
sentences2009$complete  <- (sentences2009$cumsum/sum(sentences2009$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2009$speech)$all
sentences2009$polarity <- pol$polarity
sentences2009$pos.words <- pol$pos.words
sentences2009$neg.words <- pol$neg.words
plot(sentences2009$complete, sentences2009$polarity, bty="n")
sentences2009i<- subset(sentences2009, polarity != 0)
plot(sentences2009i$complete, sentences2009i$polarity, bty="n")

### 2010 ###

sotu2010.raw <- paste(scan(file = "speeches/sotu2010.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2010 <- data.table(speech=sotu2010.raw, person="Obama")
sentences2010 <- data.table(sentSplit(sotu2010, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2010$sentence.num  <- seq(nrow(sentences2010))
# Syllables per sentence
sentences2010$syllables <- syllable_sum(sentences2010$speech)
#cumulative syllable count
sentences2010$cumsum <- cumsum(sentences2010$syllables)
#Progress in pct.
sentences2010$complete  <- (sentences2010$cumsum/sum(sentences2010$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2010$speech)$all
sentences2010$polarity <- pol$polarity
sentences2010$pos.words <- pol$pos.words
sentences2010$neg.words <- pol$neg.words
plot(sentences2010$complete, sentences2010$polarity, bty="n")
sentences2010i<- subset(sentences2010, polarity != 0)
plot(sentences2010i$complete, sentences2010i$polarity, bty="n")

### 2011 ###

sotu2011.raw <- paste(scan(file = "speeches/sotu2011.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2011 <- data.table(speech=sotu2011.raw, person="Obama")
sentences2011 <- data.table(sentSplit(sotu2011, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2011$sentence.num  <- seq(nrow(sentences2011))
# Syllables per sentence
sentences2011$syllables <- syllable_sum(sentences2011$speech)
#cumulative syllable count
sentences2011$cumsum <- cumsum(sentences2011$syllables)
#Progress in pct.
sentences2011$complete  <- (sentences2011$cumsum/sum(sentences2011$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2011$speech)$all
sentences2011$polarity <- pol$polarity
sentences2011$pos.words <- pol$pos.words
sentences2011$neg.words <- pol$neg.words
plot(sentences2011$complete, sentences2011$polarity, bty="n")
sentences2011i<- subset(sentences2011, polarity != 0)
plot(sentences2011i$complete, sentences2011i$polarity, bty="n")

### 2012 ###

sotu2012.raw <- paste(scan(file = "speeches/sotu2012.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2012 <- data.table(speech=sotu2012.raw, person="Obama")
sentences2012 <- data.table(sentSplit(sotu2012, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2012$sentence.num  <- seq(nrow(sentences2012))
# Syllables per sentence
sentences2012$syllables <- syllable_sum(sentences2012$speech)
#cumulative syllable count
sentences2012$cumsum <- cumsum(sentences2012$syllables)
#Progress in pct.
sentences2012$complete  <- (sentences2012$cumsum/sum(sentences2012$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2012$speech)$all
sentences2012$polarity <- pol$polarity
sentences2012$pos.words <- pol$pos.words
sentences2012$neg.words <- pol$neg.words
plot(sentences2012$complete, sentences2012$polarity, bty="n")
sentences2012i<- subset(sentences2012, polarity != 0)
plot(sentences2012i$complete, sentences2012i$polarity, bty="n")


### 2013 ###


sotu2013.raw <- paste(scan(file = "speeches/sotu2013.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2013 <- data.table(speech=sotu2013.raw, person="Obama")
sentences2013 <- data.table(sentSplit(sotu2013, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2013$sentence.num  <- seq(nrow(sentences2013))
# Syllables per sentence
sentences2013$syllables <- syllable_sum(sentences2013$speech)
#cumulative syllable count
sentences2013$cumsum <- cumsum(sentences2013$syllables)
#Progress in pct.
sentences2013$complete  <- (sentences2013$cumsum/sum(sentences2013$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2013$speech)$all
sentences2013$polarity <- pol$polarity
sentences2013$pos.words <- pol$pos.words
sentences2013$neg.words <- pol$neg.words
plot(sentences2013$complete, sentences2013$polarity, bty="n")
sentences2013i<- subset(sentences2013, polarity != 0)
plot(sentences2013i$complete, sentences2013i$polarity, bty="n")


### 2014 ###

sotu2014.raw <- paste(scan(file = "speeches/sotu2014.txt", what="character"), collapse=" ")

# Split into sentences
# qdap's sentSplit is modeled after dialogue data, so person field is needed
sotu2014 <- data.table(speech=sotu2014.raw, person="Obama")
sentences2014 <- data.table(sentSplit(sotu2014, "speech"))
# Add a sentence counter and remove unnecessary variables
sentences2014$sentence.num  <- seq(nrow(sentences2014))
# Syllables per sentence
sentences2014$syllables <- syllable_sum(sentences2014$speech)
#cumulative syllable count
sentences2014$cumsum <- cumsum(sentences2014$syllables)
#Progress in pct.
sentences2014$complete  <- (sentences2014$cumsum/sum(sentences2014$syllables,na.rm = TRUE))*100
pol <- polarity(sentences2014$speech)$all
sentences2014$polarity <- pol$polarity
sentences2014$pos.words <- pol$pos.words
sentences2014$neg.words <- pol$neg.words
plot(sentences2014$complete, sentences2014$polarity, bty="n")
sentences2014i<- subset(sentences2014, polarity != 0)
plot(sentences2014i$complete, sentences2014i$polarity, bty="n")

## Means CSV
x <- c(mean(sentences2009i$polarity),
mean(sentences2010i$polarity),
mean(sentences2011i$polarity),
mean(sentences2012i$polarity),
mean(sentences2013i$polarity),
mean(sentences2014i$polarity))
x  <- cbind(2009:2014, x)
line(x)
write.csv(x, "x.csv")

## Progress Plot

sen1 <- ggplot(data = sentences2009i, aes(x=complete,y=polarity)) + 
  geom_smooth(data=sentences2009i, size=0.5, color="black", method="loess", fill=NA) +
  geom_smooth(data=sentences2010i, size=0.5, color="blue", method="loess", fill=NA) +
  geom_smooth(data=sentences2011i, size=0.5, color="green", method="loess",fill=NA) +
  geom_smooth(data=sentences2012i, size=0.5, color="red", method="loess", fill=NA) +
  geom_smooth(data=sentences2013i, size=0.5, color="purple", method="loess", fill=NA) +
  geom_smooth(data=sentences2014i, size=0.5, color="orange", method="loess", fill=NA) +
  theme(panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border=element_blank()) +
  ggtitle("Sentiment Analysis, SOTU 2009-2014")+
  ylab("Sentiment of Speech")+
  xlab("Progress of Speech, in Percent")
sen1

